@@ -68,15 +68,15 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
     x = await account.get_nft_data()
     collection_address = x['collection_address'].to_string()
     owner_address = x['owner_address'].to_string()
-
+    nft_address = Address(addr).to_string(is_user_friendly=False)
     content_url = await get_nft_content_url(client, x['content'], collection_address)
 
     s = time.time()
     if items:
         if str(x['index']) in items:
             content = items[str(x['index'])]
-        elif Address(addr).to_string(is_user_friendly=False) in items:
-            content = items[Address(addr).to_string(is_user_friendly=False)]
+        elif nft_address in items:
+            content = items[nft_address]
         else:
             content = await get(content_url)
     else:
@@ -84,7 +84,7 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
 
     collection_content = await get_collection_content(client, x['collection_address'].to_string())
     result = {
-        'address': Address(addr).to_string(is_user_friendly=False),
+        'address': nft_address,
         'collection': {
             'address': collection_address,
             'name': collection_content.get('name'),
